@@ -1,9 +1,17 @@
-package Pod::Weaver::Plugin::EnsurePod5;
+package Pod::Weaver::Plugin::EnsurePod5 4.018;
 # ABSTRACT: ensure that the Pod5 translator has been run on this document
-$Pod::Weaver::Plugin::EnsurePod5::VERSION = '4.017';
+
 use Moose;
 with 'Pod::Weaver::Role::Preparer';
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 use Pod::Elemental::Transformer::Pod5;
@@ -21,12 +29,12 @@ sub _strip_nonpod {
 
   # XXX: This is really stupid. -- rjbs, 2009-10-24
 
-  foreach my $i (reverse 0 .. $#{ $node->children }) {
+  foreach my $i (reverse 0 .. $node->children->$#*) {
     my $para = $node->children->[$i];
 
     if ($para->isa('Pod::Elemental::Element::Pod5::Nonpod')) {
       if ($para->content !~ /\S/) {
-        splice @{ $node->children }, $i, 1
+        splice $node->children->@*, $i, 1
       } else {
         confess "can't cope with a Nonpod element with non-whitespace content";
       }
@@ -62,7 +70,7 @@ Pod::Weaver::Plugin::EnsurePod5 - ensure that the Pod5 translator has been run o
 
 =head1 VERSION
 
-version 4.017
+version 4.018
 
 =head1 OVERVIEW
 
@@ -70,9 +78,20 @@ This plugin is very, very simple:  it runs the Pod5 transformer on the input
 document and removes any leftover whitespace-only Nonpod elements.  If
 non-whitespace-only Nonpod elements are found, an exception is raised.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
