@@ -1,12 +1,20 @@
-package Pod::Weaver::Plugin::SingleEncoding;
+package Pod::Weaver::Plugin::SingleEncoding 4.018;
 # ABSTRACT: ensure that there is exactly one =encoding of known value
-$Pod::Weaver::Plugin::SingleEncoding::VERSION = '4.017';
+
 use Moose;
 with(
   'Pod::Weaver::Role::Dialect',
   'Pod::Weaver::Role::Finalizer',
 );
 
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 use namespace::autoclean;
 
 use Pod::Elemental::Selectors -all;
@@ -108,7 +116,7 @@ Pod::Weaver::Plugin::SingleEncoding - ensure that there is exactly one =encoding
 
 =head1 VERSION
 
-version 4.017
+version 4.018
 
 =head1 OVERVIEW
 
@@ -128,9 +136,20 @@ expectations, set the C<encoding> attribute by hand.
 No actual validation of the encoding is done.  Pod::Weaver, after all, deals in
 text rather than bytes.
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
