@@ -1,8 +1,16 @@
 use strict;
 use warnings;
-package Pod::Weaver::PluginBundle::Default;
+package Pod::Weaver::PluginBundle::Default 4.018;
 # ABSTRACT: a bundle for the most commonly-needed prep work for a pod document
-$Pod::Weaver::PluginBundle::Default::VERSION = '4.017';
+
+# BEGIN BOILERPLATE
+use v5.20.0;
+use warnings;
+use utf8;
+no feature 'switch';
+use experimental qw(postderef postderef_qq); # This experiment gets mainlined.
+# END BOILERPLATE
+
 #pod =head1 OVERVIEW
 #pod
 #pod This is the bundle used by default (specifically by Pod::Weaver's
@@ -86,7 +94,7 @@ Pod::Weaver::PluginBundle::Default - a bundle for the most commonly-needed prep
 
 =head1 VERSION
 
-version 4.017
+version 4.018
 
 =head1 OVERVIEW
 
@@ -125,9 +133,20 @@ It is nearly equivalent to the following:
   [Authors]
   [Legal]
 
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
