@@ -1,6 +1,6 @@
-package Pod::Weaver::Role::Section;
+package Pod::Weaver::Role::Section 4.018;
 # ABSTRACT: a plugin that will get a section into a woven document
-$Pod::Weaver::Role::Section::VERSION = '4.017';
+
 use Moose::Role;
 with 'Pod::Weaver::Role::Plugin';
 
@@ -34,7 +34,18 @@ Pod::Weaver::Role::Section - a plugin that will get a section into a woven docum
 
 =head1 VERSION
 
-version 4.017
+version 4.018
+
+=head1 PERL VERSION SUPPORT
+
+This module has the same support period as perl itself:  it supports the two
+most recent versions of perl.  (That is, if the most recently released version
+is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 IMPLEMENTING
 
@@ -48,7 +59,7 @@ free to behave differently if it's needed to do something really cool.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
